==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/iot/kotlin/inputs/TopicRuleErrorActionFirehoseArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.iot.kotlin.inputs

import com.pulumi.aws.iot.inputs.TopicRuleErrorActionFirehoseArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property batchMode The payload that contains a JSON array of records will be sent to Kinesis Firehose via a batch call.
 * @property deliveryStreamName The delivery stream name.
 * @property roleArn The IAM role ARN that grants access to the Amazon Kinesis Firehose stream.
 * @property separator A character separator that is used to separate records written to the Firehose stream. Valid values are: '\n' (newline), '\t' (tab), '\r\n' (Windows newline), ',' (comma).
 */
public data class TopicRuleErrorActionFirehoseArgs(
    public val batchMode: Output<Boolean>? = null,
    public val deliveryStreamName: Output<String>,
    public val roleArn: Output<String>,
    public val separator: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.iot.inputs.TopicRuleErrorActionFirehoseArgs> {
    override fun toJava(): com.pulumi.aws.iot.inputs.TopicRuleErrorActionFirehoseArgs =
        com.pulumi.aws.iot.inputs.TopicRuleErrorActionFirehoseArgs.builder()
            .batchMode(batchMode?.applyValue({ args0 -> args0 }))
            .deliveryStreamName(deliveryStreamName.applyValue({ args0 -> args0 }))
            .roleArn(roleArn.applyValue({ args0 -> args0 }))
            .separator(separator?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TopicRuleErrorActionFirehoseArgs].
 */
@PulumiTagMarker
public class TopicRuleErrorActionFirehoseArgsBuilder internal constructor() {
    private var batchMode: Output<Boolean>? = null

    private var deliveryStreamName: Output<String>? = null

    private var roleArn: Output<String>? = null

    private var separator: Output<String>? = null

    /**
     * @param value The payload that contains a JSON array of records will be sent to Kinesis Firehose via a batch call.
     */
    @JvmName("soychcgwxwjywvag")
    public suspend fun batchMode(`value`: Output<Boolean>) {
        this.batchMode = value
    }

    /**
     * @param value The delivery stream name.
     */
    @JvmName("cqkpfnucqgkryfig")
    public suspend fun deliveryStreamName(`value`: Output<String>) {
        this.deliveryStreamName = value
    }

    /**
     * @param value The IAM role ARN that grants access to the Amazon Kinesis Firehose stream.
     */
    @JvmName("mshmqmnnynciylcg")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value A character separator that is used to separate records written to the Firehose stream. Valid values are: '\n' (newline), '\t' (tab), '\r\n' (Windows newline), ',' (comma).
     */
    @JvmName("wyfdqjlexcoxsniy")
    public suspend fun separator(`value`: Output<String>) {
        this.separator = value
    }

    /**
     * @param value The payload that contains a JSON array of records will be sent to Kinesis Firehose via a batch call.
     */
    @JvmName("gaaxrioadxkqlmhb")
    public suspend fun batchMode(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.batchMode = mapped
    }

    /**
     * @param value The delivery stream name.
     */
    @JvmName("smpxmhjanfmyivsa")
    public suspend fun deliveryStreamName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deliveryStreamName = mapped
    }

    /**
     * @param value The IAM role ARN that grants access to the Amazon Kinesis Firehose stream.
     */
    @JvmName("nlqeonjfqkadrysp")
    public suspend fun roleArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    /**
     * @param value A character separator that is used to separate records written to the Firehose stream. Valid values are: '\n' (newline), '\t' (tab), '\r\n' (Windows newline), ',' (comma).
     */
    @JvmName("aacysbqpxbedrtya")
    public suspend fun separator(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.separator = mapped
    }

    internal fun build(): TopicRuleErrorActionFirehoseArgs = TopicRuleErrorActionFirehoseArgs(
        batchMode = batchMode,
        deliveryStreamName = deliveryStreamName ?: throw PulumiNullFieldException("deliveryStreamName"),
        roleArn = roleArn ?: throw PulumiNullFieldException("roleArn"),
        separator = separator,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/iot/kotlin/inputs/TopicRuleErrorActionFirehoseArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.iot.kotlin.inputs

import com.pulumi.aws.iot.inputs.TopicRuleErrorActionFirehoseArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property batchMode The payload that contains a JSON array of records will be sent to Kinesis Firehose via a batch call.
 * @property deliveryStreamName The delivery stream name.
 * @property roleArn The IAM role ARN that grants access to the Amazon Kinesis Firehose stream.
 * @property separator A character separator that is used to separate records written to the Firehose stream. Valid values are: '\n' (newline), '\t' (tab), '\r\n' (Windows newline), ',' (comma).
 */
public data class TopicRuleErrorActionFirehoseArgs(
    public val batchMode: Output<Boolean>? = null,
    public val deliveryStreamName: Output<String>,
    public val roleArn: Output<String>,
    public val separator: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.iot.inputs.TopicRuleErrorActionFirehoseArgs> {
    override fun toJava(): com.pulumi.aws.iot.inputs.TopicRuleErrorActionFirehoseArgs =
        com.pulumi.aws.iot.inputs.TopicRuleErrorActionFirehoseArgs.builder()
            .batchMode(batchMode?.applyValue({ args0 -> args0 }))
            .deliveryStreamName(deliveryStreamName.applyValue({ args0 -> args0 }))
            .roleArn(roleArn.applyValue({ args0 -> args0 }))
            .separator(separator?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TopicRuleErrorActionFirehoseArgs].
 */
@PulumiTagMarker
public class TopicRuleErrorActionFirehoseArgsBuilder internal constructor() {
    private var batchMode: Output<Boolean>? = null

    private var deliveryStreamName: Output<String>? = null

    private var roleArn: Output<String>? = null

    private var separator: Output<String>? = null

    /**
     * @param value The payload that contains a JSON array of records will be sent to Kinesis Firehose via a batch call.
     */
    @JvmName("eotpaalfbevjgcet")
    public suspend fun batchMode(`value`: Output<Boolean>) {
        this.batchMode = value
    }

    /**
     * @param value The delivery stream name.
     */
    @JvmName("qmpbmryxpwfbhygl")
    public suspend fun deliveryStreamName(`value`: Output<String>) {
        this.deliveryStreamName = value
    }

    /**
     * @param value The IAM role ARN that grants access to the Amazon Kinesis Firehose stream.
     */
    @JvmName("vesvbksveoppevdv")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value A character separator that is used to separate records written to the Firehose stream. Valid values are: '\n' (newline), '\t' (tab), '\r\n' (Windows newline), ',' (comma).
     */
    @JvmName("vqphjpqsgxigjxpd")
    public suspend fun separator(`value`: Output<String>) {
        this.separator = value
    }

    /**
     * @param value The payload that contains a JSON array of records will be sent to Kinesis Firehose via a batch call.
     */
    @JvmName("inaxadjgbfxtawkb")
    public suspend fun batchMode(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.batchMode = mapped
    }

    /**
     * @param value The delivery stream name.
     */
    @JvmName("iambqudhfglemkgs")
    public suspend fun deliveryStreamName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deliveryStreamName = mapped
    }

    /**
     * @param value The IAM role ARN that grants access to the Amazon Kinesis Firehose stream.
     */
    @JvmName("ihrjdoavunhjmksj")
    public suspend fun roleArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    /**
     * @param value A character separator that is used to separate records written to the Firehose stream. Valid values are: '\n' (newline), '\t' (tab), '\r\n' (Windows newline), ',' (comma).
     */
    @JvmName("ogrcnvbwvdldtluy")
    public suspend fun separator(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.separator = mapped
    }

    internal fun build(): TopicRuleErrorActionFirehoseArgs = TopicRuleErrorActionFirehoseArgs(
        batchMode = batchMode,
        deliveryStreamName = deliveryStreamName ?: throw PulumiNullFieldException("deliveryStreamName"),
        roleArn = roleArn ?: throw PulumiNullFieldException("roleArn"),
        separator = separator,
    )
}
